<?xml version="1.0" encoding="UTF-8" ?>
<!-- XSL stylesheet for inserting headers and footers in topics in the CICS Information Center -->
<!-- To use this stylesheet, specify /XSL:"path"\cics_header_footer.xsl on the IDWB command, 
     where "path" is the relative path from the directory where the command is run, to the directory
     containing this stylesheet -->
<xsl:stylesheet version="1.0"
                xmlns:date="http://exslt.org/dates-and-times"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:saxon="http://icl.com/saxon"
                extension-element-prefixes="saxon">
  <!-- This stylesheet modifies the behaviour of IDWB-supplied stylesheet idit2htm.xsl, which is the default
       stylesheet that is appplied to transform a DITA topic to XHTML. Note that the DITA topic to which the
       transform is applied is considerably changed from the source that was created by the author. Earlier 
       stages in the transform resolve conrefs, insert links to related topics, and add attributes to elements
       in the topic -->
  <xsl:import href="idit2htm.xsl" />
  <!-- Override the supplied template for generating breadcrumbs, because we want to insert them at a specific point
       in the header. Default behaviour will place breadcrumbs before the header -->
  <xsl:template name="generateBreadcrumbs"/>
  <!-- Override the (empty) supplied template for generating the header -->
  <xsl:template name="gen-user-header">
    <!-- First line -->
    <xsl:call-template name="brand-mark" />
    <span class="runningheader">
      <xsl:call-template name="product-description" />
      <xsl:call-template name="operating-system" />
    </span>
    <br />
    <!-- Second line -->
    <!--xsl:call-template name="breadcrumbs" /-->
    <!-- End of header -->
    <hr size="1" width="100%" align="left" />
    <br />
  </xsl:template>
  <!-- Override the (empty) supplied template for generating the footer -->
  <xsl:template name="gen-user-footer">
    <br />
    <span class="runningfooter">
      <!-- First line -->
      <xsl:call-template name="information-type" />
      <xsl:call-template name="information-unit" />
      <hr size="1" width="100%" align="left"/>
      <!-- Second line -->
      <xsl:call-template name="rate-the-page" />
      <br />
      <br />
      <!-- Third line -->
      <xsl:call-template name="last-update" />
      <br />
      <!-- Fourth line -->
      <xsl:call-template name="display-url" />
    </span>
  </xsl:template>

  <xsl:template name="brand-mark">
    <!-- Empty - we don't use a brand mark --></xsl:template>

  <xsl:template name="product-description">
    <!-- Product description and version -->
    <!-- Should be extracted from a file -->
    <strong>CICS VSAM Recovery for z/OS, Version 4.2</strong>
    <!-- Operating system is optional, and included in product description --></xsl:template>

  <xsl:template name="operating-system">
    <!-- Empty - We support just one operating system, and it's included in the product description --></xsl:template>

  <xsl:template name="breadcrumbs">
    <!-- Use the supplied breadcrumb generation -->
    <xsl:apply-templates select="*[contains(@class,' topic/related-links ')]" mode="breadcrumb"/>
  </xsl:template>

  <xsl:template name="information-type">
    <!-- Information type - icon + text -->
    <xsl:variable name="concept-icon">concept_obj.gif</xsl:variable>
    <xsl:variable name="ref-icon">reference_obj.gif</xsl:variable>
    <xsl:variable name="task-icon">task_obj.gif</xsl:variable>
    <xsl:variable name="type-icon">
      <xsl:choose>
        <xsl:when test="/*[contains(@class, ' concept/concept ')]">
          <xsl:value-of select="$concept-icon"/>
        </xsl:when>
        <xsl:when test="/*[contains(@class, ' task/task ')]">
          <xsl:value-of select="$task-icon"/>
        </xsl:when>
        <xsl:when test="/*[contains(@class, ' reference/reference ')]">
          <xsl:value-of select="$ref-icon"/>
        </xsl:when>
        <xsl:otherwise></xsl:otherwise><!-- leave null -->
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="type-label">
      <xsl:choose>
        <xsl:when test="/*[contains(@class, ' concept/concept ')]">Concept topic</xsl:when>
        <xsl:when test="/*[contains(@class, ' task/task ')]">Task topic</xsl:when>
        <xsl:when test="/*[contains(@class, ' reference/reference ')]">Reference topic</xsl:when>
        <xsl:otherwise></xsl:otherwise><!-- leave null -->
      </xsl:choose>
    </xsl:variable>
   
    <xsl:if test="normalize-space($type-icon) and normalize-space($type-label)">
      <br/>
      <xsl:for-each select="descendant::*
        [contains(@class, ' topic/link ')]
        [@type='footer-graphic']
        [contains(@href,$type-icon)]
        [1]">
        <img border="0" src="{@href}"/>
      </xsl:for-each>
      <strong>
        <xsl:value-of select="$type-label"/>
        <xsl:text>    </xsl:text>
      </strong>
    </xsl:if>
  </xsl:template>

  <xsl:template name="information-unit">
    <xsl:for-each select="descendant::*
      [contains(@class, ' topic/link ')]
      [@type='footer-relpdf'][1]">
      <xsl:text> Can also be found in: </xsl:text>
      <xsl:call-template name="makelink"/>
    </xsl:for-each>
  </xsl:template>

  <xsl:template name="rate-the-page">
    <!-- link to feedback page -->
    <xsl:for-each select="descendant::*
      [contains(@class, ' topic/link ')]
      [@type='footer-feedback']
      [1]">
      <xsl:call-template name="makelink"/>
    </xsl:for-each>
  </xsl:template>

  <xsl:template name="last-update">
    <!-- get insert the graphic -->
    <xsl:for-each select="descendant::*
      [contains(@class, ' topic/link ')]
      [@type='footer-graphic']
      [contains(@href,'timestamp.gif')]
      [1]">
      <img border="0" src="{@href}" alt="" style="margin-right:8 border:0; valign:middle"/>
      <xsl:text>   </xsl:text>
    </xsl:for-each>
    <xsl:text>Last updated: </xsl:text>
    <!-- Format the date -->
    <xsl:value-of select="date:month-name()" />
    <xsl:text> </xsl:text>
    <xsl:value-of select="date:day-in-month()" />
    <xsl:text>, </xsl:text>
    <xsl:value-of select="date:year()" />
    <xsl:text> </xsl:text>
    <!-- Format the time -->
    <xsl:text></xsl:text>
    <xsl:value-of select="date:hour-in-day()" />
    <xsl:text>:</xsl:text>
    <xsl:value-of select="date:minute-in-hour()" />
    <xsl:text>:</xsl:text>
    <xsl:value-of select="date:second-in-minute()" />
  </xsl:template>


  <xsl:template name="display-url">
    <!-- Use Javescript for dynamic display -->
    <script type="text/javascript">document.write(document.URL)</script>
  </xsl:template>
  <!--main template for setting up all links after the body - applied to the related-links container-->
  <xsl:template match="*[contains(@class,' topic/related-links ')]" name="topic.related-links">
    <div>
      <xsl:call-template name="commonattributes"/>

      <xsl:call-template name="ul-child-links"/><!--handle child/descendants outside of linklists in collection-type=unordered or choice-->

      <xsl:call-template name="ol-child-links"/><!--handle child/descendants outside of linklists in collection-type=ordered/sequence-->

      <xsl:call-template name="next-prev-parent-links"/><!--handle next and previous links-->

      <xsl:call-template name="concept-links"/><!--sort remaining concept links by type-->

      <xsl:call-template name="task-links"/><!--sort remaining task links by type-->

      <xsl:call-template name="reference-links"/><!--sort remaining reference links by type-->

      <xsl:call-template name="footer-links"/><!-- handle special links that appear in the footer -->

      <xsl:call-template name="relinfo-links"/><!--handle remaining untyped and unknown-type links-->
      <!--linklists - last but not least, create all the linklists and their links, with no sorting or re-ordering-->
      <xsl:apply-templates select="*[contains(@class,' topic/linklist ')]"/>
    </div>
  </xsl:template>

  <xsl:template name="footer-links">
    <!--related reference - all the related reference links that haven't already been covered as a child/descendant/ancestor/next/previous/prerequisite, and aren't in a linklist-->
    <xsl:if test="descendant::*
          [contains(@class, ' topic/link ')]
          [not(ancestor::*[contains(@class,' topic/linklist ')])]
          [not(@role='child' or @role='descendant' or @role='ancestor' or @role='parent' or @role='next' or @role='previous')]
          [not(@importance='required' and (not(@role) or @role='sibling' or @role='friend' or @role='cousin'))]
          [@type='footer-relpdf' or @type='footer-feedback']"></xsl:if>
  </xsl:template>

  <xsl:template name="relinfo-links">
    <!--other info- - not currently sorting by role, since already mixing any number of types in here-->
    <!--if there are links not covered by any of the other routines - ie, not in a linklist, not a child or descendant, not a concept/task/reference, not ancestor/next/previous, not prerequisite - create a section for them and create the links-->
    <xsl:if test="descendant::*
          [contains(@class, ' topic/link ')]
          [not(ancestor::*[contains(@class,' topic/linklist ')])]
          [not(@role='child' or @role='descendant' or @role='ancestor' or @role='parent' or @role='next' or @role='previous' or @type='concept' or @type='task' or @type='reference' or @type='alternate-pdf')]
          [not(@importance='required' and (not(@role) or @role='sibling' or @role='friend' or @role='cousin'))]
          [not(@type='footer-relpdf' or @type='footer-feedback' or @type='footer-graphic')]">
      <div class="relinfo">
        <strong>
          <xsl:call-template name="getString">
            <xsl:with-param name="stringName" select="'Related information'"/>
          </xsl:call-template>
        </strong>
        <br/>
        <!--once section is created, create the links, using the same rules as bove plus a uniqueness check-->
        <xsl:for-each select="descendant::*
          [not(ancestor::*[contains(@class,' topic/linklist ')])]
          [generate-id(.)=generate-id(key('link',concat(ancestor::*[contains(@class, ' topic/related-links ')]/parent::*[contains(@class, ' topic/topic ')]/@id, ' ', @href,@type,@role,@platform,@audience,@importance,@outputclass,@keyref,@scope,@format,@otherrole,@product,@otherprops,@rev,@class,child::*))[1])]
          [contains(@class, ' topic/link ')]
          [not(@role='child' or @role='descendant' or @role='ancestor' or @role='parent' or @role='next' or @role='previous' or @type='concept' or @type='task' or @type='reference')]
          [not(@importance='required' and (not(@role) or @role='sibling' or @role='friend' or @role='cousin'))]
          [not(@type='footer-relpdf' or @type='footer-feedback' or @type='footer-graphic')]">
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </div>
    </xsl:if>
  </xsl:template>
  <!--creating the actual link-->
  <xsl:template name="makelink">
    <xsl:call-template name="linkdupinfo"/>
    <xsl:call-template name="flagit"/>
    <xsl:call-template name="start-revflag"/>
    <a>
      <xsl:call-template name="commonattributes"/>
      <xsl:attribute name="href">
        <xsl:call-template name="href"/>
      </xsl:attribute>
      <xsl:if test="@scope='external' or @type='external' or ((@format='PDF' or @format='pdf') and not(@scope='local'))">
        <xsl:attribute name="target">_blank</xsl:attribute>
      </xsl:if>
      <!--create hover help if desc exists-->
      <xsl:if test="*[contains(@class, ' topic/desc ')]">
        <xsl:variable name="hoverhelp">
          <xsl:apply-templates select="*[contains(@class, ' topic/desc ')]" mode="text-only"/>
        </xsl:variable>
        <xsl:attribute name="title">
          <xsl:value-of select="normalize-space($hoverhelp)"/>
        </xsl:attribute>
      </xsl:if>
      <!-- insert image if required -->
      <xsl:if test="contains(@href,'.pdf')">
        <img border="0">
          <xsl:attribute name="src">
            <xsl:call-template name="build-directory-path">
              <xsl:with-param name="input" select="@href" />
            </xsl:call-template>
            <!-- append the file name -->
            <xsl:text>pdf.gif</xsl:text>
          </xsl:attribute>
        </img>

      </xsl:if>
      <!--use linktext as linktext if it exists, otherwise use href as linktext-->
      <xsl:choose>
        <xsl:when test="*[contains(@class, ' topic/linktext ')]">
          <xsl:apply-templates select="*[contains(@class, ' topic/linktext ')]"/>
        </xsl:when>
        <xsl:otherwise><!--use href-->
          <xsl:call-template name="href"/>
        </xsl:otherwise>
      </xsl:choose>
    </a>
    <xsl:call-template name="end-revflag"/>
  </xsl:template>

  <!-- With a file and directory path as input, build the directory path -->
  <xsl:template name="build-directory-path">
    <xsl:param name="input"/>
    <!-- Unless the input contains a delimiter, there is nothing to do -->
    <xsl:if test="contains($input, '/')">
      <!-- output what is before the delimeter, and the delimiter itself -->
      <xsl:value-of select="substring-before($input, '/')" />
      <xsl:text>/</xsl:text>
      <!-- call the template again with whatever follows the delimiter -->
      <xsl:variable name="temp" select="substring-after($input, '/')" />
      <xsl:if test="contains($temp, '/')">
        <xsl:call-template name="build-directory-path">
          <xsl:with-param name="input" select="$temp" />
        </xsl:call-template>
      </xsl:if>
    </xsl:if>
  </xsl:template>


  <!--creating the actual link-->
  <xsl:template name="makegraphic">
       <xsl:if test="contains(@href,'.gif')">
        <img border="0" src="{@href}"/>
      </xsl:if>
  </xsl:template>

</xsl:stylesheet>
